contexttools.detach_instrument_marks_attached_to_component
==========================================================

.. autofunction:: abjad.tools.contexttools.detach_instrument_marks_attached_to_component.detach_instrument_marks_attached_to_component
